@@ -327,6 +327,8 @@
 		 (cpi-pop)
 		 (if (eq? mode 'code)
 		     (set! skip (cons 'skip-1 (cdr skip)))))
+		((error)
+		 stmt)
 		(else
 		 (error "unhandled cpp stmt")))
 	      (cons 'cpp-stmt stmt)))
@@ -361,10 +363,6 @@
 		;;((and (simple-format #t "chs=>~S\n" (read-chseq ch)) #f))
 		((read-chseq ch) => identity)
 		((assq-ref chrtab ch) => (lambda (t) (cons t (string ch))))
-	        ((eqv? ch #\\)
-		 (let ((ch (read-char)))
-		   (cond ((eqv? #\newline ch) (iter (read-char)))
-			 (else (unread-char ch) (cons #\\ "\\")))))
 		(else (cons ch (string ch))))))
 	    )
 
