@@ -573,8 +573,8 @@
      ("if" "(" expression ")" statement ($prec "then")
       ($$ `(if ,$3 ,$5)))
      ("if" "(" expression ")" statement "else" statement
-      ($$ `(if ,$3 ,$5 ,7)))
-     ("switch" "(" expression ")" statement ($$ `(switch (TBD))))
+      ($$ `(if ,$3 ,$5 ,$7)))
+     ("switch" "(" expression ")" statement ($$ `(switch ,$3 ,$5)))
      )
 
     (iteration-statement
