@@ -458,7 +458,12 @@
 (define (udecl->mspec decl . rest)
 
   (define (cnvt-array-size size-spec)
-    (with-output-to-string (lambda () (pretty-print-c99 size-spec))))
+    ;; This needs to be completed in order to be able to pretty-print
+    ;; constant expressions.
+    (sxml-match size-spec
+      ((p-expr (fixed ,size)) size)
+      ((p-expr (ident ,size)) size)
+      (,otherwise size-spec)))
 
   (define (unwrap-specl specl)
     (let ((tspec (cadadr specl)))
